==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/release/CodeArtifactOptions.java <==
package io.github.cdklabs.projen.release;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.913Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.release.CodeArtifactOptions")
@software.amazon.jsii.Jsii.Proxy(CodeArtifactOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface CodeArtifactOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) GitHub secret which contains the AWS access key ID to use when publishing packages to AWS CodeArtifact.
     * <p>
     * This property must be specified only when publishing to AWS CodeArtifact (<code>registry</code> contains AWS CodeArtifact URL).
     * <p>
     * Default: "AWS_ACCESS_KEY_ID"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getAccessKeyIdSecret() {
        return null;
    }

    /**
     * (experimental) ARN of AWS role to be assumed prior to get authorization token from AWS CodeArtifact This property must be specified only when publishing to AWS CodeArtifact (`registry` contains AWS CodeArtifact URL).
     * <p>
     * Default: undefined
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getRoleToAssume() {
        return null;
    }

    /**
     * (experimental) GitHub secret which contains the AWS secret access key to use when publishing packages to AWS CodeArtifact.
     * <p>
     * This property must be specified only when publishing to AWS CodeArtifact (<code>registry</code> contains AWS CodeArtifact URL).
     * <p>
     * Default: "AWS_SECRET_ACCESS_KEY"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getSecretAccessKeySecret() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CodeArtifactOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CodeArtifactOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<CodeArtifactOptions> {
        java.lang.String accessKeyIdSecret;
        java.lang.String roleToAssume;
        java.lang.String secretAccessKeySecret;

        /**
         * Sets the value of {@link CodeArtifactOptions#getAccessKeyIdSecret}
         * @param accessKeyIdSecret GitHub secret which contains the AWS access key ID to use when publishing packages to AWS CodeArtifact.
         *                          This property must be specified only when publishing to AWS CodeArtifact (<code>registry</code> contains AWS CodeArtifact URL).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder accessKeyIdSecret(java.lang.String accessKeyIdSecret) {
            this.accessKeyIdSecret = accessKeyIdSecret;
            return this;
        }

        /**
         * Sets the value of {@link CodeArtifactOptions#getRoleToAssume}
         * @param roleToAssume ARN of AWS role to be assumed prior to get authorization token from AWS CodeArtifact This property must be specified only when publishing to AWS CodeArtifact (`registry` contains AWS CodeArtifact URL).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder roleToAssume(java.lang.String roleToAssume) {
            this.roleToAssume = roleToAssume;
            return this;
        }

        /**
         * Sets the value of {@link CodeArtifactOptions#getSecretAccessKeySecret}
         * @param secretAccessKeySecret GitHub secret which contains the AWS secret access key to use when publishing packages to AWS CodeArtifact.
         *                              This property must be specified only when publishing to AWS CodeArtifact (<code>registry</code> contains AWS CodeArtifact URL).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder secretAccessKeySecret(java.lang.String secretAccessKeySecret) {
            this.secretAccessKeySecret = secretAccessKeySecret;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CodeArtifactOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public CodeArtifactOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CodeArtifactOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CodeArtifactOptions {
        private final java.lang.String accessKeyIdSecret;
        private final java.lang.String roleToAssume;
        private final java.lang.String secretAccessKeySecret;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.accessKeyIdSecret = software.amazon.jsii.Kernel.get(this, "accessKeyIdSecret", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.roleToAssume = software.amazon.jsii.Kernel.get(this, "roleToAssume", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.secretAccessKeySecret = software.amazon.jsii.Kernel.get(this, "secretAccessKeySecret", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.accessKeyIdSecret = builder.accessKeyIdSecret;
            this.roleToAssume = builder.roleToAssume;
            this.secretAccessKeySecret = builder.secretAccessKeySecret;
        }

        @Override
        public final java.lang.String getAccessKeyIdSecret() {
            return this.accessKeyIdSecret;
        }

        @Override
        public final java.lang.String getRoleToAssume() {
            return this.roleToAssume;
        }

        @Override
        public final java.lang.String getSecretAccessKeySecret() {
            return this.secretAccessKeySecret;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAccessKeyIdSecret() != null) {
                data.set("accessKeyIdSecret", om.valueToTree(this.getAccessKeyIdSecret()));
            }
            if (this.getRoleToAssume() != null) {
                data.set("roleToAssume", om.valueToTree(this.getRoleToAssume()));
            }
            if (this.getSecretAccessKeySecret() != null) {
                data.set("secretAccessKeySecret", om.valueToTree(this.getSecretAccessKeySecret()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.release.CodeArtifactOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CodeArtifactOptions.Jsii$Proxy that = (CodeArtifactOptions.Jsii$Proxy) o;

            if (this.accessKeyIdSecret != null ? !this.accessKeyIdSecret.equals(that.accessKeyIdSecret) : that.accessKeyIdSecret != null) return false;
            if (this.roleToAssume != null ? !this.roleToAssume.equals(that.roleToAssume) : that.roleToAssume != null) return false;
            return this.secretAccessKeySecret != null ? this.secretAccessKeySecret.equals(that.secretAccessKeySecret) : that.secretAccessKeySecret == null;
        }

        @Override
        public final int hashCode() {
            int result = this.accessKeyIdSecret != null ? this.accessKeyIdSecret.hashCode() : 0;
            result = 31 * result + (this.roleToAssume != null ? this.roleToAssume.hashCode() : 0);
            result = 31 * result + (this.secretAccessKeySecret != null ? this.secretAccessKeySecret.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/release/CodeArtifactOptions.java <==
package io.github.cdklabs.projen.release;

/**
 * (experimental) Options for publishing packages to AWS CodeArtifact.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.579Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.release.CodeArtifactOptions")
@software.amazon.jsii.Jsii.Proxy(CodeArtifactOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface CodeArtifactOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) GitHub secret which contains the AWS access key ID to use when publishing packages to AWS CodeArtifact.
     * <p>
     * This property must be specified only when publishing to AWS CodeArtifact (<code>npmRegistryUrl</code> contains AWS CodeArtifact URL).
     * <p>
     * Default: - When the `authProvider` value is set to
     * `CodeArtifactAuthProvider.ACCESS_AND_SECRET_KEY_PAIR`, the default is
     * "AWS_ACCESS_KEY_ID". For `CodeArtifactAuthProvider.GITHUB_OIDC`, this
     * value must be left undefined.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getAccessKeyIdSecret() {
        return null;
    }

    /**
     * (experimental) Provider to use for authorizing requests to AWS CodeArtifact.
     * <p>
     * Default: CodeArtifactAuthProvider.ACCESS_AND_SECRET_KEY_PAIR
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.release.CodeArtifactAuthProvider getAuthProvider() {
        return null;
    }

    /**
     * (experimental) ARN of AWS role to be assumed prior to get authorization token from AWS CodeArtifact This property must be specified only when publishing to AWS CodeArtifact (<code>registry</code> contains AWS CodeArtifact URL).
     * <p>
     * When using the <code>CodeArtifactAuthProvider.GITHUB_OIDC</code> auth provider, this value must be defined.
     * <p>
     * Default: undefined
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getRoleToAssume() {
        return null;
    }

    /**
     * (experimental) GitHub secret which contains the AWS secret access key to use when publishing packages to AWS CodeArtifact.
     * <p>
     * This property must be specified only when publishing to AWS CodeArtifact (<code>npmRegistryUrl</code> contains AWS CodeArtifact URL).
     * <p>
     * Default: - When the `authProvider` value is set to
     * `CodeArtifactAuthProvider.ACCESS_AND_SECRET_KEY_PAIR`, the default is
     * "AWS_SECRET_ACCESS_KEY". For `CodeArtifactAuthProvider.GITHUB_OIDC`, this
     * value must be left undefined.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getSecretAccessKeySecret() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CodeArtifactOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CodeArtifactOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<CodeArtifactOptions> {
        java.lang.String accessKeyIdSecret;
        io.github.cdklabs.projen.release.CodeArtifactAuthProvider authProvider;
        java.lang.String roleToAssume;
        java.lang.String secretAccessKeySecret;

        /**
         * Sets the value of {@link CodeArtifactOptions#getAccessKeyIdSecret}
         * @param accessKeyIdSecret GitHub secret which contains the AWS access key ID to use when publishing packages to AWS CodeArtifact.
         *                          This property must be specified only when publishing to AWS CodeArtifact (<code>npmRegistryUrl</code> contains AWS CodeArtifact URL).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder accessKeyIdSecret(java.lang.String accessKeyIdSecret) {
            this.accessKeyIdSecret = accessKeyIdSecret;
            return this;
        }

        /**
         * Sets the value of {@link CodeArtifactOptions#getAuthProvider}
         * @param authProvider Provider to use for authorizing requests to AWS CodeArtifact.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder authProvider(io.github.cdklabs.projen.release.CodeArtifactAuthProvider authProvider) {
            this.authProvider = authProvider;
            return this;
        }

        /**
         * Sets the value of {@link CodeArtifactOptions#getRoleToAssume}
         * @param roleToAssume ARN of AWS role to be assumed prior to get authorization token from AWS CodeArtifact This property must be specified only when publishing to AWS CodeArtifact (<code>registry</code> contains AWS CodeArtifact URL).
         *                     When using the <code>CodeArtifactAuthProvider.GITHUB_OIDC</code> auth provider, this value must be defined.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder roleToAssume(java.lang.String roleToAssume) {
            this.roleToAssume = roleToAssume;
            return this;
        }

        /**
         * Sets the value of {@link CodeArtifactOptions#getSecretAccessKeySecret}
         * @param secretAccessKeySecret GitHub secret which contains the AWS secret access key to use when publishing packages to AWS CodeArtifact.
         *                              This property must be specified only when publishing to AWS CodeArtifact (<code>npmRegistryUrl</code> contains AWS CodeArtifact URL).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder secretAccessKeySecret(java.lang.String secretAccessKeySecret) {
            this.secretAccessKeySecret = secretAccessKeySecret;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CodeArtifactOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public CodeArtifactOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CodeArtifactOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CodeArtifactOptions {
        private final java.lang.String accessKeyIdSecret;
        private final io.github.cdklabs.projen.release.CodeArtifactAuthProvider authProvider;
        private final java.lang.String roleToAssume;
        private final java.lang.String secretAccessKeySecret;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.accessKeyIdSecret = software.amazon.jsii.Kernel.get(this, "accessKeyIdSecret", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.authProvider = software.amazon.jsii.Kernel.get(this, "authProvider", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.release.CodeArtifactAuthProvider.class));
            this.roleToAssume = software.amazon.jsii.Kernel.get(this, "roleToAssume", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.secretAccessKeySecret = software.amazon.jsii.Kernel.get(this, "secretAccessKeySecret", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.accessKeyIdSecret = builder.accessKeyIdSecret;
            this.authProvider = builder.authProvider;
            this.roleToAssume = builder.roleToAssume;
            this.secretAccessKeySecret = builder.secretAccessKeySecret;
        }

        @Override
        public final java.lang.String getAccessKeyIdSecret() {
            return this.accessKeyIdSecret;
        }

        @Override
        public final io.github.cdklabs.projen.release.CodeArtifactAuthProvider getAuthProvider() {
            return this.authProvider;
        }

        @Override
        public final java.lang.String getRoleToAssume() {
            return this.roleToAssume;
        }

        @Override
        public final java.lang.String getSecretAccessKeySecret() {
            return this.secretAccessKeySecret;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAccessKeyIdSecret() != null) {
                data.set("accessKeyIdSecret", om.valueToTree(this.getAccessKeyIdSecret()));
            }
            if (this.getAuthProvider() != null) {
                data.set("authProvider", om.valueToTree(this.getAuthProvider()));
            }
            if (this.getRoleToAssume() != null) {
                data.set("roleToAssume", om.valueToTree(this.getRoleToAssume()));
            }
            if (this.getSecretAccessKeySecret() != null) {
                data.set("secretAccessKeySecret", om.valueToTree(this.getSecretAccessKeySecret()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.release.CodeArtifactOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CodeArtifactOptions.Jsii$Proxy that = (CodeArtifactOptions.Jsii$Proxy) o;

            if (this.accessKeyIdSecret != null ? !this.accessKeyIdSecret.equals(that.accessKeyIdSecret) : that.accessKeyIdSecret != null) return false;
            if (this.authProvider != null ? !this.authProvider.equals(that.authProvider) : that.authProvider != null) return false;
            if (this.roleToAssume != null ? !this.roleToAssume.equals(that.roleToAssume) : that.roleToAssume != null) return false;
            return this.secretAccessKeySecret != null ? this.secretAccessKeySecret.equals(that.secretAccessKeySecret) : that.secretAccessKeySecret == null;
        }

        @Override
        public final int hashCode() {
            int result = this.accessKeyIdSecret != null ? this.accessKeyIdSecret.hashCode() : 0;
            result = 31 * result + (this.authProvider != null ? this.authProvider.hashCode() : 0);
            result = 31 * result + (this.roleToAssume != null ? this.roleToAssume.hashCode() : 0);
            result = 31 * result + (this.secretAccessKeySecret != null ? this.secretAccessKeySecret.hashCode() : 0);
            return result;
        }
    }
}
